@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import atexit
 import itertools
 import pkgutil
@@ -9,8 +7,6 @@ import getopt
 import traceback
 from collections import Counter
 
-from future.builtins import input
-
 from routersploit.core.exploit.exceptions import RoutersploitException
 from routersploit.core.exploit.utils import (
     index_modules,
@@ -39,8 +35,7 @@ import readline
 
 
 def is_libedit():
-    return "libedit" in readline.__doc__
-
+    return isinstance(readline.__doc__, str) and "libedit" in readline.__doc__
 
 class BaseInterpreter(object):
     history_file = os.path.expanduser("~/.history")
@@ -241,7 +236,7 @@ class RoutersploitInterpreter(BaseInterpreter):
             Embedded Devices
 
  Codename   : I Knew You Were Trouble
- Version    : 3.4.4
+ Version    : 3.4.6
  Homepage   : https://www.threat9.com - @threatnine
 
  Exploits: {exploits_count} Scanners: {scanners_count} Creds: {creds_count} Generic: {generic_count} Payloads: {payloads_count} Encoders: {encoders_count}
